/*
 * Copyright 2007 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.xbib.files.ftp.mock.test.core.server;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.xbib.files.ftp.mock.core.server.AbstractFtpServer;
import org.xbib.files.ftp.mock.test.AbstractTestCase;
import org.xbib.files.ftp.mock.test.PortTestUtil;
import org.xbib.files.ftp.FTPClient;
import static org.junit.jupiter.api.Assertions.assertEquals;

/**
 * Abstract superclass for tests of AbstractFtpServer subclasses that require the server thread to be started.
 *
 * @author Chris Mair
 */
public abstract class AbstractFtpServer_StartTestCase extends AbstractTestCase {

    private static final String SERVER = "localhost";

    private AbstractFtpServer ftpServer;

    @Test
    void testStartAndStop() throws Exception {
        ftpServer.setServerControlPort(PortTestUtil.getFtpServerControlPort());
        assertEquals(false, ftpServer.isStarted());

        ftpServer.start();
        Thread.sleep(200L);     // give it some time to get started
        assertEquals(true, ftpServer.isStarted());
        assertEquals(false, ftpServer.isShutdown());

        ftpServer.stop();

        assertEquals(true, ftpServer.isShutdown());
    }

    @Test
    void testCustomServerControlPort() throws Exception {
        final int SERVER_CONTROL_PORT = 9187;

        ftpServer.setServerControlPort(SERVER_CONTROL_PORT);
        ftpServer.start();

        try {
            FTPClient ftpClient = new FTPClient();
            ftpClient.connect(SERVER, SERVER_CONTROL_PORT);
        }
        finally {
            ftpServer.stop();
        }
    }

    //-------------------------------------------------------------------------
    // Test setup
    //-------------------------------------------------------------------------

    @BeforeEach
    void setUp() throws Exception {
        ftpServer = createFtpServer();
    }

    //-------------------------------------------------------------------------
    // Abstract method declarations
    //-------------------------------------------------------------------------

    protected abstract AbstractFtpServer createFtpServer();

}