/*
 * Copyright 2007 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.xbib.files.ftp.mock.test.stub;

import static org.junit.jupiter.api.Assertions.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.xbib.files.ftp.mock.core.command.Command;
import org.xbib.files.ftp.mock.core.command.CommandHandler;
import org.xbib.files.ftp.mock.core.command.InvocationRecord;
import org.xbib.files.ftp.mock.core.server.AbstractFtpServer;
import org.xbib.files.ftp.mock.core.session.Session;
import org.xbib.files.ftp.mock.stub.StubFtpServer;
import org.xbib.files.ftp.mock.stub.command.AbstractStubCommandHandler;
import org.xbib.files.ftp.mock.stub.command.CwdCommandHandler;
import org.xbib.files.ftp.mock.test.core.server.AbstractFtpServerTestCase;

import java.util.ResourceBundle;

/**
 * Unit tests for StubFtpServer. Also see {@link StubFtpServer_StartTest}
 * and {@link StubFtpServerIntegrationTest}.
 *
 * @author Chris Mair
 */
class StubFtpServerTest extends AbstractFtpServerTestCase {

    private StubFtpServer stubFtpServer;
    private AbstractStubCommandHandler commandHandler;
    private CommandHandler commandHandler_NoReplyTextBundle;

    //-------------------------------------------------------------------------
    // Extra tests  (Standard tests defined in superclass)
    //-------------------------------------------------------------------------

    @Test
    void testSetCommandHandler_NotReplyTextBundleAware() {
        stubFtpServer.setCommandHandler("ZZZ", commandHandler_NoReplyTextBundle);
        assertSame(commandHandler_NoReplyTextBundle, stubFtpServer.getCommandHandler("ZZZ"));
    }

    @Test
    void testSetCommandHandler_NullReplyTextBundle() {
        stubFtpServer.setCommandHandler("ZZZ", commandHandler);
        assertSame(commandHandler, stubFtpServer.getCommandHandler("ZZZ"));
        assertSame(stubFtpServer.getReplyTextBundle(), commandHandler.getReplyTextBundle());
    }

    @Test
    void testSetReplyTextBaseName() {
        stubFtpServer.setReplyTextBaseName("org.xbib.files.ftp.mock.test.SampleReplyText");
        CwdCommandHandler commandHandler = new CwdCommandHandler();

        // The resource bundle is passed along to new CommandHandlers (if they don't already have one) 
        stubFtpServer.setCommandHandler("CWD", commandHandler);
        ResourceBundle resourceBundle = commandHandler.getReplyTextBundle();
        assertEquals("Testing123", resourceBundle.getString("110"));
    }

    //-------------------------------------------------------------------------
    // Test setup
    //-------------------------------------------------------------------------

    @BeforeEach
    void setUp() {
        stubFtpServer = (StubFtpServer) ftpServer;

        // Create a CommandHandler instance that also implements ResourceBundleAware
        commandHandler = new AbstractStubCommandHandler() {
            protected void handleCommand(Command command, Session session, InvocationRecord invocationRecord) {
            }
        };

        // Create a CommandHandler instance that does NOT implement ResourceBundleAware
        commandHandler_NoReplyTextBundle = new CommandHandler() {
            public void handleCommand(Command command, Session session) throws Exception {
            }
        };
    }

    //-------------------------------------------------------------------------
    // Abstract method implementations
    //-------------------------------------------------------------------------

    protected AbstractFtpServer createFtpServer() {
        return new StubFtpServer();
    }

    protected CommandHandler createCommandHandler() {
        return new AbstractStubCommandHandler() {
            protected void handleCommand(Command command, Session session, InvocationRecord invocationRecord) {
            }
        };
    }

    protected void verifyCommandHandlerInitialized(CommandHandler commandHandler) {
        AbstractStubCommandHandler stubCommandHandler = (AbstractStubCommandHandler) commandHandler;
        assertSame(stubFtpServer.getReplyTextBundle(), stubCommandHandler.getReplyTextBundle());
    }

}
